#region Copyright Syncfusion Inc. 2001 - 2016
// Copyright Syncfusion Inc. 2001 - 2016. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Diagnostics;
using Syncfusion.Windows.Tools.Controls;
using Syncfusion.Windows.Tools;
using System.Xml;
using Syncfusion.Windows.Shared;
using System.ComponentModel;
using System.IO;
using Microsoft.Win32;
using WebBrowser = System.Windows.Forms.WebBrowser;
using System.Globalization;


namespace DockingDemo
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
      

        #region Constructor

        /// <summary>
        /// Constructor for Window
        /// </summary>

        public Window1()
        {
            try
            {
                InitializeComponent();
                EventsLog();
            }
            catch ( Exception ee )
            {
                MessageBox.Show( ee.Message );
            }

           
        }

       
        

       
        /// <summary>
        /// Subscribe the events while creating object
        /// </summary>  
        public void EventsLog()
        {
            // Subscribe the DockingManager events
            this.DockingManager.Loaded += new RoutedEventHandler( DockingManager_Loaded );
        }


        #endregion

        #region Helper Methods


        /// <summary>
        /// Events occur while loading docking manager
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>        
        private void DockingManager_Loaded( object sender, RoutedEventArgs e )
        {
            MenuItem menuItem = sender as MenuItem;
            this.DockingManager.CloseButtonClick += DockingManager_CloseButtonClick;
            this.DockingManager.TabClosed += DockingManager_TabClosed;
            this.DockingManager.ContextMenuItemClick += DockingManager_ContextMenuItemClick;
            this.DockingManager.DockMenuClick += DockingManager_DockMenuClick;
            (DockingManager.DocContainer as DocumentContainer).DocumentClosing += Window1_DocumentClosing;
            (DockingManager.DocContainer as DocumentContainer).CloseButtonClick += Window1_CloseButtonClick;
            
        }

        void Window1_CloseButtonClick(object sender, CloseButtonEventArgs e)
        {
            if (DockingManager.GetHeader(e.TargetItem).ToString() == "NewItem")
            {
                DockingManager.DocContainer.Items.Remove(e.TargetItem);
            }
        }

        void Window1_DocumentClosing(object sender, CancelingRoutedEventArgs e)
        {
            MessageBox.Show("A MDI is closed ");
        }

        private void DockingManager_DockMenuClick( object sender, RoutedEventArgs e )
        {
            MessageBox.Show( "A menu item is clicked. Its context is " );
        }

        private void DockingManager_ContextMenuItemClick( object sender, RoutedEventArgs e )
        {
            MessageBox.Show( "A menu item is clicked. Its context is "  );
        }

        private void DockingManager_TabClosed( object sender, CloseTabEventArgs e )
        {
            MessageBox.Show( "A tab is closed." );
            //throw new NotImplementedException();
        }

        private void DockingManager_CloseButtonClick( object sender, CloseButtonEventArgs e )
        {
            MessageBox.Show( "Close button is clicked." );
        }

        bool m_layoutflag = true;
        private void DockingManager_LayoutUpdated( object sender, EventArgs e )
        {
            if ( m_layoutflag )
            {
                SkinStorage.SetVisualStyle( this, "Office2007Blue" );
                m_layoutflag = false;
            }
        }

        /// <summary>
        /// Click event for containermode
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void windowswitchers_Click( object sender, RoutedEventArgs e )
        {
            //Switch Mode of Docking Manager
            MenuItem mi = ( MenuItem )e.OriginalSource;
            string g = mi.Header.ToString();

            for ( int i = 0; i < WindowSwitchers.Items.Count; i++ )
            {
                MenuItem mitem = ( MenuItem )WindowSwitchers.Items[ i ];
                if ( mitem.Header.ToString().Equals( g ) )
                    mitem.IsChecked = true;
                else
                    mitem.IsChecked = false;
            }
            // Set SwitchMode as Immediate
            if ( g.StartsWith( "Immediate" ) )
                DockingManager.SwitchMode = SwitchMode.Immediate;
            // Set SwitchMode as List
            else if ( g.StartsWith( "List" ) )
                DockingManager.SwitchMode = SwitchMode.List;
            // Set SwitchMode as QuickTabs
            else if ( g.StartsWith( "QuickTabs" ) )
                DockingManager.SwitchMode = SwitchMode.QuickTabs;
            // Set SwitchMode as VS2005
            else if ( g.StartsWith( "VS2005" ) )
                DockingManager.SwitchMode = SwitchMode.VS2005;
            // Set SwitchMode as VistaFlip
            else if ( g.StartsWith( "VistaFlip" ) )
                DockingManager.SwitchMode = SwitchMode.VistaFlip;
        }

        /// <summary>
        /// Click event for containermode
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ContainerMode_Click( object sender, RoutedEventArgs e )
        {
            //Changing Container Mode
            MenuItem menuItem = sender as MenuItem;
            // Set ContainerMode as MDI
            if ( menuItem.Name == "ContainerModeMDI" )
            {
                DockingManager.ContainerMode = DocumentContainerMode.MDI;
                ContainerModeMDI.IsChecked = true;
                ContainerModeTDI.IsChecked = false;
            }
            // Set ContainerMode as TDI
            else if ( menuItem.Name == "ContainerModeTDI" )
            {
                DockingManager.ContainerMode = DocumentContainerMode.TDI;
                ContainerModeMDI.IsChecked = false;
                ContainerModeTDI.IsChecked = true;
            }
        }
        #endregion

        #region Events

        /// <summary>
        /// Event log.
        /// </summary>
        /// <param name="prop"></param>
        public void AddToLog( string prop )
        {
            TextBlock tt = new TextBlock();
            tt = new TextBlock();
            tt.FontSize = 12;
            tt.Text = prop + "Occured";
            evntlog.Children.Add( tt );
            Scroll.ScrollToBottom();
        }

        /// <summary>
        /// WindowVisibility changed event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DockingManager_WindowVisibilityChanged( object sender, RoutedEventArgs e )
        {
            AddToLog( e.RoutedEvent.ToString() );
        }
        /// <summary>
        /// WindowActivated changed event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DockingManager_WindowActivated( object sender, RoutedEventArgs e )
        {
            AddToLog( e.RoutedEvent.ToString() );
        }
        /// <summary>
        /// WindowDeactivated changed event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DockingManager_WindowDeactivated( object sender, RoutedEventArgs e )
        {
            AddToLog( e.RoutedEvent.ToString() );
        }
        /// <summary>
        /// WindowDrag end event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DockingManager_WindowDragEnd( object sender, RoutedEventArgs e )
        {
            AddToLog( e.RoutedEvent.ToString() );
        }
        /// <summary>
        /// WindowDrag start event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DockingManager_WindowDragStart( object sender, RoutedEventArgs e )
        {
            AddToLog( e.RoutedEvent.ToString() );
        }
        /// <summary>
        /// BeforeContextMenuOpen event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DockingManager_BeforeContextMenuOpen( object sender, RoutedEventArgs e )
        {
            AddToLog( e.RoutedEvent.ToString() );
        }
        /// <summary>
        /// AutoHideAnimation start event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DockingManager_AutoHideAnimationStart( object sender, RoutedEventArgs e )
        {
            AddToLog( e.RoutedEvent.ToString() );
        }
        /// <summary>
        /// AutoHideAnimation stop event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void DockingManager_AutoHideAnimationStop( object sender, RoutedEventArgs e )
        {
            AddToLog( e.RoutedEvent.ToString() );
        }


        #endregion



        private void window1_Loaded( object sender, RoutedEventArgs e )
        {
            SkinStorage.SetVisualStyle( this, "Metro" );
        }

        private void NewDocument_Click( object sender, RoutedEventArgs e )
        {

            UserControl1 userControl = new UserControl1();
            ScrollViewer scrollViewer = new ScrollViewer();
            scrollViewer.HorizontalScrollBarVisibility = ScrollBarVisibility.Auto;
            scrollViewer.VerticalScrollBarVisibility = ScrollBarVisibility.Auto;
            DockingManager.SetState( userControl, DockState.Document );
            DockingManager.SetShowDockableMenuItem(userControl, false);
            DockingManager.SetShowFloatingMenuItem(userControl, false);
            DockingManager.SetShowDocumentMenuItem(userControl, true);
            DockingManager.SetHeader( userControl, "NewItem" );

            ImageSource imgSource = new BitmapImage( new Uri( @"../../Images/View.png", UriKind.Relative ) );
            ImageBrush imgBrush = new ImageBrush( imgSource );
            DockingManager.SetIcon( userControl, imgBrush );
            scrollViewer.Content = userControl;
            DocumentContainer.SetMDIBounds( userControl, new Rect( 0, 0, 450, 300 ) );
            DocumentContainer.SetCanClose( userControl, true );

         //   this.DockingManager.Children.Add(userControl);
           this.DockingManager.DocContainer.Items.Add( userControl);
        }

        private void CheckCount_Click( object sender, RoutedEventArgs e )
        {
            string msg = "{0} document(s) still be opened.";
            MessageBox.Show( string.Format( msg, this.DockingManager.DocContainer.Items.Count ), "Opened Documents", MessageBoxButton.OK );
        }
    }

    public class BooleanToVisibilityConverter : IValueConverter
    {
        #region IValueConverter Members

        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <param name="value">The value produced by the binding source.</param>
        /// <param name="targetType">The type of the binding target property.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            if ((bool)value)
            {
                return Visibility.Visible;
            }
            else
                return Visibility.Hidden;
        }

        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <param name="value">The value that is produced by the binding target.</param>
        /// <param name="targetType">The type to convert to.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }

        #endregion
    }
}
